@@ -1,7 +1,4 @@
 """
-mypythontools
-=============
-
 Some tools/functions/snippets used across projects.
 
 Official documentation - https://mypythontools.readthedocs.io/
@@ -27,10 +24,10 @@ from . import deploy
 from . import misc
 from . import pyvueeel
 
-__version__ = "0.0.29"
+__version__ = "0.0.30"
 
 __author__ = "Daniel Malachov"
 __license__ = "MIT"
 __email__ = "malachovd@seznam.cz"
 
-__all__ = ['utils', 'build', 'deploy', 'misc', 'pyvueeel']
+__all__ = ["utils", "build", "deploy", "misc", "pyvueeel"]
